@@ -161,35 +161,35 @@ class _DP8TCell(_BitCell["DP8TFactory"]):
         pg2 = ckt.instantiate(spec.nmos, name="pg2", l=spec.pg_l, w=spec.pg_w)
         pg2n = ckt.instantiate(spec.nmos, name="pg2n", l=spec.pg_l, w=spec.pg_w)
 
-        ckt.new_net("vdd", external=True, childports=(
+        ckt.new_net(name="vdd", external=True, childports=(
             pu1.ports.sourcedrain1, pu1.ports.bulk,
             pu2.ports.sourcedrain1, pu2.ports.bulk,
         ))
-        ckt.new_net("vss", external=True, childports=(
+        ckt.new_net(name="vss", external=True, childports=(
             pd1.ports.sourcedrain1, pd1.ports.bulk,
             pd2.ports.sourcedrain1, pd2.ports.bulk,
             pg1.ports.bulk, pg1n.ports.bulk,
             pg2.ports.bulk, pg2n.ports.bulk,
         ))
 
-        ckt.new_net("wl1", external=True, childports=(
+        ckt.new_net(name="wl1", external=True, childports=(
             pg1.ports.gate, pg1n.ports.gate,
         ))
-        ckt.new_net("wl2", external=True, childports=(
+        ckt.new_net(name="wl2", external=True, childports=(
             pg2.ports.gate, pg2n.ports.gate,
         ))
 
-        ckt.new_net("bl1", external=True, childports=pg1.ports.sourcedrain1)
-        ckt.new_net("bl1_n", external=True, childports=pg1n.ports.sourcedrain1)
-        ckt.new_net("bl2", external=True, childports=pg2.ports.sourcedrain1)
-        ckt.new_net("bl2_n", external=True, childports=pg2n.ports.sourcedrain1)
+        ckt.new_net(name="bl1", external=True, childports=pg1.ports.sourcedrain1)
+        ckt.new_net(name="bl1_n", external=True, childports=pg1n.ports.sourcedrain1)
+        ckt.new_net(name="bl2", external=True, childports=pg2.ports.sourcedrain1)
+        ckt.new_net(name="bl2_n", external=True, childports=pg2n.ports.sourcedrain1)
 
-        ckt.new_net("bit", external=False, childports=(
+        ckt.new_net(name="bit", external=False, childports=(
             pg1.ports.sourcedrain2, pg2.ports.sourcedrain2,
             pd1.ports.sourcedrain2, pu1.ports.sourcedrain2,
             pd2.ports.gate, pu2.ports.gate,
         ))
-        ckt.new_net("bit_n", external=False, childports=(
+        ckt.new_net(name="bit_n", external=False, childports=(
             pg1n.ports.sourcedrain2, pg2n.ports.sourcedrain2,
             pd2.ports.sourcedrain2, pu2.ports.sourcedrain2,
             pd1.ports.gate, pu1.ports.gate,
