@@ -77,25 +77,25 @@ class SRAMCellDP8T:
         pg2b = ckt.instantiate(passgate_mos, name="pg2b", **passgate_params)
 
         # Nets
-        ckt.new_net("wl1", external=True, childports=(pg1.ports.gate, pg1b.ports.gate))
-        ckt.new_net("wl2", external=True, childports=(pg2.ports.gate, pg2b.ports.gate))
-        ckt.new_net("bl1", external=True, childports=pg1.ports.sourcedrain2)
-        ckt.new_net("bl1b", external=True, childports=pg1b.ports.sourcedrain2)
-        ckt.new_net("bl2", external=True, childports=pg2.ports.sourcedrain2)
-        ckt.new_net("bl2b", external=True, childports=pg2b.ports.sourcedrain2)
-        ckt.new_net("vdd", external=True, childports=(
+        ckt.new_net(name="wl1", external=True, childports=(pg1.ports.gate, pg1b.ports.gate))
+        ckt.new_net(name="wl2", external=True, childports=(pg2.ports.gate, pg2b.ports.gate))
+        ckt.new_net(name="bl1", external=True, childports=pg1.ports.sourcedrain2)
+        ckt.new_net(name="bl1b", external=True, childports=pg1b.ports.sourcedrain2)
+        ckt.new_net(name="bl2", external=True, childports=pg2.ports.sourcedrain2)
+        ckt.new_net(name="bl2b", external=True, childports=pg2b.ports.sourcedrain2)
+        ckt.new_net(name="vdd", external=True, childports=(
             pu1.ports.sourcedrain1, pu1.ports.bulk, pu2.ports.sourcedrain1, pu2.ports.bulk,
         ))
-        ckt.new_net("vss", external=True, childports=(
+        ckt.new_net(name="vss", external=True, childports=(
             pd1.ports.sourcedrain2, pd1.ports.bulk, pd2.ports.sourcedrain2, pd2.ports.bulk,
             pg1.ports.bulk, pg2.ports.bulk,
             pg1b.ports.bulk, pg2b.ports.bulk,
         ))
-        ckt.new_net("n", external=False, childports=(
+        ckt.new_net(name="n", external=False, childports=(
             pu1.ports.gate, pd1.ports.gate, pu2.ports.sourcedrain2, pd2.ports.sourcedrain1,
             pg1.ports.sourcedrain1, pg2.ports.sourcedrain1,
         ))
-        ckt.new_net("nb", external=False, childports=(
+        ckt.new_net(name="nb", external=False, childports=(
             pu1.ports.sourcedrain2, pd1.ports.sourcedrain1, pu2.ports.gate, pd2.ports.gate,
             pg1b.ports.sourcedrain1, pg2b.ports.sourcedrain1,
         ))
