@@ -115,32 +115,32 @@ class _SP6TCell(_BitCell["SP6TFactory"]):
         pg1 = ckt.instantiate(spec.nmos, name="pg1", l=spec.pg_l, w=spec.pg_w)
         pg2 = ckt.instantiate(spec.nmos, name="pg2", l=spec.pg_l, w=spec.pg_w)
 
-        ckt.new_net("vdd", external=True, childports=(
+        ckt.new_net(name="vdd", external=True, childports=(
             pu1.ports.sourcedrain1, pu1.ports.bulk,
             pu2.ports.sourcedrain2, pu2.ports.bulk,
         ))
-        ckt.new_net("vss", external=True, childports=(
+        ckt.new_net(name="vss", external=True, childports=(
             pd1.ports.sourcedrain1, pd1.ports.bulk,
             pd2.ports.sourcedrain2, pd2.ports.bulk,
             pg1.ports.bulk, pg2.ports.bulk,
         ))
 
-        ckt.new_net("wl", external=True, childports=(
+        ckt.new_net(name="wl", external=True, childports=(
             pg1.ports.gate, pg2.ports.gate,
         ))
-        ckt.new_net("bl", external=True, childports=(
+        ckt.new_net(name="bl", external=True, childports=(
             pg1.ports.sourcedrain1,
         ))
-        ckt.new_net("bl_n", external=True, childports=(
+        ckt.new_net(name="bl_n", external=True, childports=(
             pg2.ports.sourcedrain1,
         ))
 
-        ckt.new_net("bit", external=False, childports=(
+        ckt.new_net(name="bit", external=False, childports=(
             pg1.ports.sourcedrain2,
             pd1.ports.sourcedrain2, pu1.ports.sourcedrain2,
             pd2.ports.gate, pu2.ports.gate,
         ))
-        ckt.new_net("bit_n", external=False, childports=(
+        ckt.new_net(name="bit_n", external=False, childports=(
             pg2.ports.sourcedrain2,
             pd2.ports.sourcedrain1, pu2.ports.sourcedrain1,
             pd1.ports.gate, pu1.ports.gate,
